Index: STARTERKIT/STARTERKIT.info.txt
===================================================================
RCS file: /cvs/drupal-contrib/contributions/themes/zen/STARTERKIT/STARTERKIT.info.txt,v
retrieving revision 1.2
diff -u -p -r1.2 STARTERKIT.info.txt
--- STARTERKIT/STARTERKIT.info.txt	8 May 2009 15:05:29 -0000	1.2
+++ STARTERKIT/STARTERKIT.info.txt	25 May 2009 21:09:50 -0000
@@ -61,8 +61,8 @@ stylesheets[print][] = print.css
   ; To add a new region, copy Zen's page.tpl.php to your sub-theme's directory,
   ; add a line line to this file, and then add the new variable to your
   ; page.tpl.php template.
-regions[left]           = left sidebar
-regions[right]          = right sidebar
+regions[left]           = primary sidebar
+regions[right]          = secondary sidebar
 regions[navbar]         = navigation bar
 regions[content_top]    = content top
 regions[content_bottom] = content bottom
Index: zen/ie6.css
===================================================================
RCS file: /cvs/drupal-contrib/contributions/themes/zen/zen/ie6.css,v
retrieving revision 1.5
diff -u -p -r1.5 ie6.css
--- zen/ie6.css	19 Feb 2009 14:48:15 -0000	1.5
+++ zen/ie6.css	25 May 2009 21:09:50 -0000
@@ -29,8 +29,8 @@ body
 
 #content,
 #navbar,
-#sidebar-left,
-#sidebar-right /* Floating divs */
+#sidebar-primary,
+#sidebar-secondary /* Floating divs */
 {
   display: inline; /* display inline or double your floated margin! [1] */
   overflow: hidden; /* in ie6, overflow auto is broken [2] and so is overflow visible [3] */
Index: zen/layout-fixed.css
===================================================================
RCS file: /cvs/drupal-contrib/contributions/themes/zen/zen/layout-fixed.css,v
retrieving revision 1.11
diff -u -p -r1.11 layout-fixed.css
--- zen/layout-fixed.css	27 Apr 2009 05:01:54 -0000	1.11
+++ zen/layout-fixed.css	25 May 2009 21:09:50 -0000
@@ -150,14 +150,14 @@ body
   padding: 0; /* DO NOT CHANGE. Add padding or margin to #content-inner. */
 }
 
-.sidebar-left #content
+.sidebar-primary #content
 {
   width: 760px;
-  margin-left: 200px; /* The width of #sidebar-left. */
+  margin-left: 200px; /* The width of #sidebar-primary. */
   margin-right: -960px; /* Negative value of #content's width + left margin. */
 }
 
-.sidebar-right #content
+.sidebar-secondary #content
 {
   width: 760px;
   margin-left: 0;
@@ -167,7 +167,7 @@ body
 .two-sidebars #content
 {
   width: 560px;
-  margin-left: 200px; /* The width of #sidebar-left */
+  margin-left: 200px; /* The width of #sidebar-primary */
   margin-right: -760px; /* Negative value of #content's width + left margin. */
 }
 
@@ -193,8 +193,8 @@ body
 }
 
 .with-navbar #content,
-.with-navbar #sidebar-left,
-.with-navbar #sidebar-right
+.with-navbar #sidebar-primary,
+.with-navbar #sidebar-secondary
 {
   margin-top: 3.6em; /* Set this to the same value as the navbar height above. */
 }
@@ -235,36 +235,36 @@ body
 */
 
 /*
- * Sidebar-left
+ * Sidebar-primary
  */
-#sidebar-left
+#sidebar-primary
 {
   float: left;
   width: 200px;
   margin-left: 0;
-  margin-right: -200px; /* Negative value of #sidebar-left's width + left margin. */
-  padding: 0; /* DO NOT CHANGE. Add padding or margin to #sidebar-left-inner. */
+  margin-right: -200px; /* Negative value of #sidebar-primary's width + left margin. */
+  padding: 0; /* DO NOT CHANGE. Add padding or margin to #sidebar-primary-inner. */
 }
 
-#sidebar-left-inner
+#sidebar-primary-inner
 {
   margin: 0 20px 0 0;
   padding: 0;
 }
 
 /*
- * Sidebar-right
+ * Sidebar-secondary
  */
-#sidebar-right
+#sidebar-secondary
 {
   float: left;
   width: 200px;
-  margin-left: 760px; /* Width of content + sidebar-left. */
-  margin-right: -960px; /* Negative value of #sidebar-right's width + left margin. */
-  padding: 0; /* DO NOT CHANGE. Add padding or margin to #sidebar-right-inner. */
+  margin-left: 760px; /* Width of content + sidebar-primary. */
+  margin-right: -960px; /* Negative value of #sidebar-secondary's width + left margin. */
+  padding: 0; /* DO NOT CHANGE. Add padding or margin to #sidebar-secondary-inner. */
 }
 
-#sidebar-right-inner
+#sidebar-secondary-inner
 {
   margin: 0 0 0 20px;
   padding: 0;
@@ -306,8 +306,8 @@ body
 #header,
 #content,
 #navbar,
-#sidebar-left,
-#sidebar-right,
+#sidebar-primary,
+#sidebar-secondary,
 #footer,
 #closure-blocks
 {
Index: zen/layout-liquid.css
===================================================================
RCS file: /cvs/drupal-contrib/contributions/themes/zen/zen/layout-liquid.css,v
retrieving revision 1.12
diff -u -p -r1.12 layout-liquid.css
--- zen/layout-liquid.css	27 Apr 2009 05:01:54 -0000	1.12
+++ zen/layout-liquid.css	25 May 2009 21:09:50 -0000
@@ -149,22 +149,22 @@ body
   padding: 0;
 }
 
-.sidebar-left #content-inner
+.sidebar-primary #content-inner
 {
-  padding-left: 200px; /* The width + left margin of #sidebar-left. */
+  padding-left: 200px; /* The width + left margin of #sidebar-primary. */
   padding-right: 0;
 }
 
-.sidebar-right #content-inner
+.sidebar-secondary #content-inner
 {
   padding-left: 0;
-  padding-right: 200px; /* The width + right margin of #sidebar-right. */
+  padding-right: 200px; /* The width + right margin of #sidebar-secondary. */
 }
 
 .two-sidebars #content-inner
 {
-  padding-left: 200px; /* The width + left margin of #sidebar-left. */
-  padding-right: 200px; /* The width + right margin of #sidebar-right. */
+  padding-left: 200px; /* The width + left margin of #sidebar-primary. */
+  padding-right: 200px; /* The width + right margin of #sidebar-secondary. */
 }
 
 /*
@@ -183,8 +183,8 @@ body
 }
 
 .with-navbar #content,
-.with-navbar #sidebar-left,
-.with-navbar #sidebar-right
+.with-navbar #sidebar-primary,
+.with-navbar #sidebar-secondary
 {
   margin-top: 3.6em; /* Set this to the same value as the navbar height above. */
 }
@@ -225,36 +225,36 @@ body
 */
 
 /*
- * Sidebar-left
+ * Sidebar-primary
  */
-#sidebar-left
+#sidebar-primary
 {
   float: left;
   width: 200px;
   margin-left: 0;
-  margin-right: -200px; /* Negative value of #sidebar-left's width + left margin. */
-  padding: 0; /* DO NOT CHANGE. Add padding or margin to #sidebar-left-inner. */
+  margin-right: -200px; /* Negative value of #sidebar-primary's width + left margin. */
+  padding: 0; /* DO NOT CHANGE. Add padding or margin to #sidebar-primary-inner. */
 }
 
-#sidebar-left-inner
+#sidebar-primary-inner
 {
   margin: 0 20px 0 0;
   padding: 0;
 }
 
 /*
- * Sidebar-right
+ * Sidebar-secondary
  */
-#sidebar-right
+#sidebar-secondary
 {
   float: right;
   width: 200px;
-  margin-left: -200px; /* Negative value of #sidebar-right's width + right margin. */
+  margin-left: -200px; /* Negative value of #sidebar-secondary's width + right margin. */
   margin-right: 0;
-  padding: 0; /* DO NOT CHANGE. Add padding or margin to #sidebar-right-inner. */
+  padding: 0; /* DO NOT CHANGE. Add padding or margin to #sidebar-secondary-inner. */
 }
 
-#sidebar-right-inner
+#sidebar-secondary-inner
 {
   margin: 0 0 0 20px;
   padding: 0;
@@ -296,8 +296,8 @@ body
 #header,
 #content,
 #navbar,
-#sidebar-left,
-#sidebar-right,
+#sidebar-primary,
+#sidebar-secondary,
 #footer,
 #closure-blocks
 {
Index: zen/maintenance-page.tpl.php
===================================================================
RCS file: /cvs/drupal-contrib/contributions/themes/zen/zen/maintenance-page.tpl.php,v
retrieving revision 1.4
diff -u -p -r1.4 maintenance-page.tpl.php
--- zen/maintenance-page.tpl.php	3 May 2009 11:11:53 -0000	1.4
+++ zen/maintenance-page.tpl.php	25 May 2009 21:09:50 -0000
@@ -104,15 +104,15 @@
       <?php endif; ?>
 
       <?php if ($left): ?>
-        <div id="sidebar-left"><div id="sidebar-left-inner" class="region region-left">
+        <div id="sidebar-primary"><div id="sidebar-primary-inner" class="region region-left">
           <?php print $left; ?>
-        </div></div> <!-- /#sidebar-left-inner, /#sidebar-left -->
+        </div></div> <!-- /#sidebar-primary-inner, /#sidebar-primary -->
       <?php endif; ?>
 
       <?php if ($right): ?>
-        <div id="sidebar-right"><div id="sidebar-right-inner" class="region region-right">
+        <div id="sidebar-secondary"><div id="sidebar-secondary-inner" class="region region-right">
           <?php print $right; ?>
-        </div></div> <!-- /#sidebar-right-inner, /#sidebar-right -->
+        </div></div> <!-- /#sidebar-secondary-inner, /#sidebar-secondary -->
       <?php endif; ?>
 
     </div></div> <!-- /#main-inner, /#main -->
Index: zen/pages.css
===================================================================
RCS file: /cvs/drupal-contrib/contributions/themes/zen/zen/pages.css,v
retrieving revision 1.6
diff -u -p -r1.6 pages.css
--- zen/pages.css	3 May 2009 09:53:28 -0000	1.6
+++ zen/pages.css	25 May 2009 21:09:50 -0000
@@ -227,30 +227,30 @@ ul.links li
 }
 
 /*
- * Left sidebar
+ * Primary sidebar (on left in LTR languages, on right in RTL)
  *
- * Remember to NOT add padding or margin to your #sidebar-left
+ * Remember to NOT add padding or margin to your #sidebar-primary
  * (see the layout.css file.)
  */
-#sidebar-left
+#sidebar-primary
 {
 }
 
-#sidebar-left-inner
+#sidebar-primary-inner
 {
 }
 
 /*
- * Right sidebar
+ * Secondary sidebar (on right in LTR languages, on left in RTL)
  *
- * Remember to NOT add padding or margin to your #sidebar-right
+ * Remember to NOT add padding or margin to your #sidebar-secondary
  * (see the layout.css file.)
  */
-#sidebar-right
+#sidebar-secondary
 {
 }
 
-#sidebar-right-inner
+#sidebar-secondary-inner
 {
 }
 
Index: zen/print.css
===================================================================
RCS file: /cvs/drupal-contrib/contributions/themes/zen/zen/print.css,v
retrieving revision 1.4
diff -u -p -r1.4 print.css
--- zen/print.css	13 Feb 2009 06:39:42 -0000	1.4
+++ zen/print.css	25 May 2009 21:09:50 -0000
@@ -52,7 +52,7 @@ body,
 }
 
 /* Hide sidebars and nav elements */
-#skip-to-nav, #navbar, #sidebar-left, #sidebar-right, #footer,
+#skip-to-nav, #navbar, #sidebar-primary, #sidebar-secondary, #footer,
 .breadcrumb, div.tabs, .links, .taxonomy,
 .book-navigation, .forum-topic-navigation, .pager, .feed-icons
 {
Index: zen/template.php
===================================================================
RCS file: /cvs/drupal-contrib/contributions/themes/zen/zen/template.php,v
retrieving revision 1.51
diff -u -p -r1.51 template.php
--- zen/template.php	30 Apr 2009 12:04:30 -0000	1.51
+++ zen/template.php	25 May 2009 21:09:51 -0000
@@ -153,6 +153,13 @@ function zen_preprocess_page(&$vars, $ho
   if (theme_get_setting('zen_wireframes')) {
     $classes[] = 'with-wireframes'; // Optionally add the wireframes style.
   }
+  // Rename Drupal core's sidebar-* classes to match the names of our sidebars.
+  if ($pos = array_search('sidebar-left', $classes)) {
+    $classes[$pos] = 'sidebar-primary';
+  }
+  elseif ($pos = array_search('sidebar-right', $classes)) {
+    $classes[$pos] = 'sidebar-secondary';
+  }
   $vars['body_classes_array'] = $classes;
   $vars['body_classes'] = implode(' ', $classes); // Concatenate with spaces.
 }
Index: zen/wireframes.css
===================================================================
RCS file: /cvs/drupal-contrib/contributions/themes/zen/zen/wireframes.css,v
retrieving revision 1.4
diff -u -p -r1.4 wireframes.css
--- zen/wireframes.css	2 Feb 2009 03:38:46 -0000	1.4
+++ zen/wireframes.css	25 May 2009 21:09:51 -0000
@@ -12,8 +12,8 @@
 .with-wireframes #content-inner,
 .with-wireframes #content-inner>*,
 .with-wireframes #navbar-inner,
-.with-wireframes #sidebar-left-inner,
-.with-wireframes #sidebar-right-inner,
+.with-wireframes #sidebar-primary-inner,
+.with-wireframes #sidebar-secondary-inner,
 .with-wireframes #footer-inner
 {
   margin: 1px;
Index: zen/zen.info
===================================================================
RCS file: /cvs/drupal-contrib/contributions/themes/zen/zen/zen.info,v
retrieving revision 1.15
diff -u -p -r1.15 zen.info
--- zen/zen.info	7 May 2009 17:50:17 -0000	1.15
+++ zen/zen.info	25 May 2009 21:09:51 -0000
@@ -55,8 +55,8 @@ conditional-stylesheets[if lte IE 5][all
   ; "[content_top]" in the .info file means there should be a $content_top
   ; variable in the page.tpl.php file.) The text after the equals sign is a
   ; descriptive text used on the admin/build/blocks page.
-regions[left]           = left sidebar
-regions[right]          = right sidebar
+regions[left]           = primary sidebar
+regions[right]          = secondary sidebar
 regions[navbar]         = navigation bar
 regions[content_top]    = content top
 regions[content_bottom] = content bottom

Index: zen/page.tpl.php
===================================================================
RCS file: /cvs/drupal-contrib/contributions/themes/zen/zen/page.tpl.php,v
retrieving revision 1.25
diff -u -p -r1.25 page.tpl.php
--- zen/page.tpl.php	3 May 2009 11:11:53 -0000	1.25
+++ zen/page.tpl.php	25 May 2009 21:09:50 -0000
@@ -41,11 +41,11 @@
  *   - node-type-[node type]: When viewing a single node, the type of that node.
  *     For example, if the node is a "Blog entry" it would result in "node-type-blog".
  *     Note that the machine name will often be in a short form of the human readable label.
  *   The following only apply with the default 'left' and 'right' block regions:
  *     - two-sidebars: When both sidebars have content.
  *     - no-sidebars: When no sidebar content exists.
  *     - one-sidebar and sidebar-left or sidebar-right: A combination of the two classes
  *       when only one of the two sidebars have content.
  *
  * Site identity:
  * - $front_page: The URL of the front page. Use this instead of $base_path,
@@ -74,8 +74,8 @@
  * - $help: Dynamic help text, mostly for admin pages.
  * - $content: The main content of the current Drupal page.
  * - $feed_icons: A string of all feed icons for the current page.
  * - $left: The HTML for the left sidebar.
  * - $right: The HTML for the right sidebar.
  *
  * Footer/closing data:
  * - $footer_message: The footer message as defined in the admin settings.
@@ -215,15 +215,15 @@
       <?php endif; ?>
 
       <?php if ($left): ?>
-        <div id="sidebar-left"><div id="sidebar-left-inner" class="region region-left">
+        <div id="sidebar-primary"><div id="sidebar-primary-inner" class="region region-left">
           <?php print $left; ?>
-        </div></div> <!-- /#sidebar-left-inner, /#sidebar-left -->
+        </div></div> <!-- /#sidebar-primary-inner, /#sidebar-primary -->
       <?php endif; ?>
 
       <?php if ($right): ?>
-        <div id="sidebar-right"><div id="sidebar-right-inner" class="region region-right">
+        <div id="sidebar-secondary"><div id="sidebar-secondary-inner" class="region region-right">
           <?php print $right; ?>
-        </div></div> <!-- /#sidebar-right-inner, /#sidebar-right -->
+        </div></div> <!-- /#sidebar-secondary-inner, /#sidebar-secondary -->
       <?php endif; ?>
 
     </div></div> <!-- /#main-inner, /#main -->
@@ -41,11 +41,11 @@
  *     For example, if the node is a "Blog entry" it would result in "node-type-blog".
  *     Note that the machine name will often be in a short form of the human readable label.
- *   The following only apply with the default 'left' and 'right' block regions:
+ *   The following only apply with the default 'primary' and 'secondary' block regions:
  *     - two-sidebars: When both sidebars have content.
  *     - no-sidebars: When no sidebar content exists.
@@ -41,11 +41,11 @@
  *     - two-sidebars: When both sidebars have content.
  *     - no-sidebars: When no sidebar content exists.
- *     - one-sidebar and sidebar-left or sidebar-right: A combination of the two classes
- *       when only one of the two sidebars have content.
+ *     - one-sidebar and sidebar-primary or sidebar-secondary: A combination of
+ *       the two classes when only one of the two sidebars have content.
  *
  * Site identity:
@@ -74,8 +74,8 @@
  * - $content: The main content of the current Drupal page.
  * - $feed_icons: A string of all feed icons for the current page.
- * - $left: The HTML for the left sidebar.
- * - $right: The HTML for the right sidebar.
+ * - $left: The HTML for the primary sidebar.
+ * - $right: The HTML for the secondary sidebar.
  *
  * Footer/closing data: